@@ -1,5 +1,5 @@
 {- 
-    Copyright 2011-2015 Mario Blazevic
+    Copyright 2011-2018 Mario Blazevic
 
     This file is part of the Streaming Component Combinators (SCC) project.
 
@@ -24,6 +24,7 @@ import Control.Applicative (Applicative, Alternative, pure, (<*>), (*>), empty,
 import Control.Monad (MonadPlus, liftM, liftM2, mzero, mplus)
 import Data.List (find, minimumBy, nub, sort)
 import Data.Monoid (Monoid(..))
+import Data.Semigroup (Semigroup(..))
 import System.Environment (getArgs)
 
 import Test.Tasty.QuickCheck (Arbitrary(..), Gen, Property, property, (==>), (.&&.), forAll, oneof, resize, sized, whenFail)
@@ -54,16 +55,22 @@ instance Show (Described a) where
 instance Show (TestParser a r) where
    show (TestParser d) = show d
 
-instance (Arbitrary r, Monoid r, Show r) => Arbitrary (TestParser a r) where
+instance (Arbitrary r, Semigroup r, Monoid r, Show r) => Arbitrary (TestParser a r) where
    arbitrary = fmap TestParser arbitrary
 
-instance Monoid a => Monoid (Described a) where
-   mempty = Described "mempty" mempty
-   Described d1 p1 `mappend` Described d2 p2 = Described (d1 ++ " `mappend` " ++ d2) (mappend p1 p2)
+instance Semigroup a => Semigroup (Described a) where
+   Described d1 p1 <> Described d2 p2 = Described (d1 ++ " <> " ++ d2) (p1 <> p2)
 
-instance Monoid r => Monoid (TestParser a r) where
+instance (Semigroup a, Monoid a) => Monoid (Described a) where
+   mempty = Described "mempty" mempty
+   mappend = (<>)
+
+instance Semigroup r => Semigroup (TestParser a r) where
+   TestParser d1 <> TestParser d2 = TestParser (d1 <> d2)
+
+instance (Semigroup r, Monoid r) => Monoid (TestParser a r) where
    mempty = TestParser mempty
-   TestParser d1 `mappend` TestParser d2 = TestParser (d1 `mappend` d2)
+   mappend = (<>)
 
 instance EqProp a => EqProp (Described a) where
    Described _ x =-= Described _ y = x =-= y
@@ -250,7 +257,7 @@ testJoin = ("join",
 
 canonicalResults p = sort $ nub $ completeResults p
 
-instance forall a r. (Arbitrary r, Monoid r, Show r) => Arbitrary (Described (Parser a [Bool] r)) where
+instance forall a r. (Arbitrary r, Semigroup r, Monoid r, Show r) => Arbitrary (Described (Parser a [Bool] r)) where
    arbitrary = sized $ 
                \n-> if n == 0
                     then return (Described "empty" failure)
@@ -272,6 +279,9 @@ instance forall a r. (Arbitrary r, Monoid r, Show r) => Arbitrary (Described (Pa
 instance (Monoid r, Show r) => Show (Parser a [Bool] r) where
    show p = showWith (showBoolFun show) show p
 
+instance Semigroup Bool where
+   (<>) = (||)
+
 instance Monoid Bool where
    mempty = False
    mappend = (||)
